==> breeze-5.0.95.tar.xz: breeze-5.0.95/kstyle/breezepropertynames.cpp <==
/*************************************************************************
 * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
 *                                                                       *
 * This program is free software; you can redistribute it and/or modify  *
 * it under the terms of the GNU General Public License as published by  *
 * the Free Software Foundation; either version 2 of the License, or     *
 * (at your option) any later version.                                   *
 *                                                                       *
 * This program is distributed in the hope that it will be useful,       *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 * GNU General Public License for more details.                          *
 *                                                                       *
 * You should have received a copy of the GNU General Public License     *
 * along with this program; if not, write to the                         *
 * Free Software Foundation, Inc.,                                       *
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 *************************************************************************/


#include "breezepropertynames.h"

namespace Breeze
{

    const char* const PropertyNames::noAnimations = "_kde_no_animations";
    const char* const PropertyNames::noWindowGrab = "_kde_no_window_grab";
    const char* const PropertyNames::netWMForceShadow( "_KDE_NET_WM_FORCE_SHADOW" );
    const char* const PropertyNames::netWMSkipShadow( "_KDE_NET_WM_SKIP_SHADOW" );
    const char* const PropertyNames::sidePanelView = "_kde_side_panel_view";
    const char* const PropertyNames::toolButtonAlignment = "_kde_toolButton_alignment";

}

==> breeze-5.3.1.tar.xz: breeze-5.3.1/kstyle/breezepropertynames.cpp <==
/*************************************************************************
 * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
 *                                                                       *
 * This program is free software; you can redistribute it and/or modify  *
 * it under the terms of the GNU General Public License as published by  *
 * the Free Software Foundation; either version 2 of the License, or     *
 * (at your option) any later version.                                   *
 *                                                                       *
 * This program is distributed in the hope that it will be useful,       *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 * GNU General Public License for more details.                          *
 *                                                                       *
 * You should have received a copy of the GNU General Public License     *
 * along with this program; if not, write to the                         *
 * Free Software Foundation, Inc.,                                       *
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 *************************************************************************/


#include "breezepropertynames.h"

namespace Breeze
{

    const char PropertyNames::noAnimations[] = "_kde_no_animations";
    const char PropertyNames::noWindowGrab[] = "_kde_no_window_grab";
    const char PropertyNames::netWMForceShadow[] = "_KDE_NET_WM_FORCE_SHADOW";
    const char PropertyNames::netWMSkipShadow[] = "_KDE_NET_WM_SKIP_SHADOW";
    const char PropertyNames::sidePanelView[] = "_kde_side_panel_view";
    const char PropertyNames::toolButtonAlignment[] = "_kde_toolButton_alignment";

}
